@@ -1216,11 +1216,10 @@ AppLog& AppLog::operator<< (AppLog& (*pfManipulator)(AppLog&))
 
 AppLog& AppLog::operator<< (ostream& (*pfManipulator)(ostream&))
 {
-  (*pfManipulator)(*(dynamic_cast<ostream*>(this)));
+	(*pfManipulator)(polyreference_cast<ostream>(this));
+	return  reference_cast<AppLog>(this) ;
+}
 
-  return  *this ;
 }
 
 #endif
-
-}
