@@ -30,6 +30,12 @@
 #include <ucommon/platform.h>
 #endif
 
+#ifdef  _MSWINDOWS_
+typedef LONG atomic_t;
+#else
+typedef int atomic_t;
+#endif
+
 namespace ucommon {
 
 /**
@@ -56,21 +62,29 @@ public:
     class __EXPORT counter
     {
     private:
-        volatile long value;
+        mutable volatile atomic_t value;
 
     public:
-        counter(long initial = 0);
+        counter(atomic_t initial = 0);
 
-        long operator++();
-        long operator--();
-        long operator+=(long offset);
-        long operator-=(long offset);
+        // fetch add/sub optimized semantics
+        atomic_t fetch_add(atomic_t offset = 1) volatile;
+        atomic_t fetch_sub(atomic_t offset = 1) volatile;
 
-        inline operator long()
-            {return (long)(value);}
+        atomic_t operator++() volatile;
+        atomic_t operator--() volatile;
+        atomic_t operator+=(atomic_t offset) volatile;
+        atomic_t operator-=(atomic_t offset) volatile;
+        atomic_t get() volatile;
+        void clear() volatile;
 
-        inline long operator*()
-            {return value;}
+        inline operator atomic_t() volatile {
+            return get();
+        }
+
+        inline atomic_t operator*() volatile {
+            return get();
+        }
     };
 
     /**
@@ -81,7 +95,11 @@ public:
     class __EXPORT spinlock
     {
     private:
-        volatile long value;
+#ifdef  __GNUC__
+        mutable volatile atomic_t value __attribute__ ((aligned(16)));
+#else
+        mutable volatile atomic_t value;
+#endif
 
     public:
         /**
@@ -94,15 +112,30 @@ public:
          * by doing something else.  One suggestion is using thread::yield.
          * @return true if acquired.
          */
-        bool acquire(void);
+        bool acquire(void) volatile;
+
+        /**
+         * Wait for and aquire spinlock.
+         */
+        void wait(void) volatile;
 
         /**
          * Release an acquired spinlock.
          */
-        void release(void);
+        void release(void) volatile;
     };
+
+    /**
+     * Atomically aligned heap alloc function.
+     * @param size of memory to allocate.
+     * @return pointer or NULL if cannot alloc.
+     */
+    void *alloc(size_t size);
 };
 
+// for abi7
+typedef atomic Atomic;
+
 } // namespace ucommon
 
 #endif
